@@ -57,7 +57,7 @@ void TestJob::start()
 
 void TestJob::stop()
 {
-    if ((status() == Running) || (status() == Aborted) || (status() == Moving) || (status() == Finished)) {
+    if ((status() == Running) || (status() == Aborted) || (status() == Moving)) {
         setStatus(Stopped);
     }
 }
@@ -589,3 +589,5 @@ void SchedulerTest::testShouldUpdate_data()
 }
 
 QTEST_MAIN(SchedulerTest)
+
+#include "moc_schedulertest.cpp"
